Case class

Constructors

Case(String upperCase, String lowerCase)
const

Properties

character → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
lowerCase → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upperCase → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited